@@ -125,7 +125,9 @@ class Interval:
         Return a translated string of the short 1 or 2 char string
         in nn. Possible values for nn are: dd, d, m, M, a, aa, p
         """
-        return _i("interval|%s" % Interval.__nn_to_interval_quality[nn])
+        # Hack, just to xgettext should not grab the string for translation
+        xx = _i
+        return xx("interval|%s" % Interval.__nn_to_interval_quality[nn])
     nn_to_translated_quality = staticmethod(nn_to_translated_quality)
     def number_name(steps):
         try:
