@@ -38,6 +38,9 @@ def win32_play_wav_file(filename):
 def linux_play_wav_file(filename):
     print "play_wav_file not set. Not playing:", filename
 
+def linux_play_midi_file(fileame):
+    print "play_midi_file not set. Not playing:", filename
+
 if sys.platform == 'win32':
     import winsound
     play_wav_file = win32_play_wav_file
