@@ -67,7 +67,7 @@ class Teacher(cfg.ConfigUtils):
                 def remove_timeout(self=self):
                     self.m_timeout_handle = None
                     self.g_view.new_question()
-                self.m_timeout_handle = gobject.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
+                self.m_timeout_handle = gobject.timeout_add(int(self.get_float('seconds_before_new_question')*1000),  remove_timeout)
     def end_practise(self):
         if self.m_timeout_handle:
             gobject.source_remove(self.m_timeout_handle)
