@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome
+import gtk
 import gobject
 import gu
 from specialwidgets import QuestionNameCheckButtonTable
@@ -25,7 +25,7 @@ import utils
 import soundcard
 import dataparser
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
     # valid values for self.q_status:
@@ -36,7 +36,7 @@ class Teacher(abstract.LessonbasedTeacher):
     CORRECT = 1
     ALL_CORRECT = 2
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.ChordLessonfile
     def new_question(self):
         """
@@ -122,7 +122,7 @@ class Gui(abstract.LessonbasedGui):
         # practise_box #
         ################
         hbox = gu.bHBox(self.practise_box)
-        hbox.set_spacing(gnome.ui.PAD)
+        hbox.set_spacing(gu.PAD)
         spacebox = gtk.HBox()
         hbox.pack_start(spacebox)
 
@@ -130,13 +130,13 @@ class Gui(abstract.LessonbasedGui):
         hbox.pack_start(table, False)
         hsep = gtk.HSeparator()
         table.attach(hsep, 0, 5, 1, 2, xoptions=gtk.FILL,
-                     yoptions=gtk.FILL, xpadding=0, ypadding=gnome.ui.PAD_SMALL)
+                     yoptions=gtk.FILL, xpadding=0, ypadding=gu.PAD_SMALL)
         self.g_vsep1 = gtk.VSeparator()
         table.attach(self.g_vsep1, 1, 2, 0, 4,
-                     xoptions=0, xpadding=gnome.ui.PAD)
+                     xoptions=0, xpadding=gu.PAD)
         self.g_vsep2 = gtk.VSeparator()
         table.attach(self.g_vsep2, 3, 4, 0, 4,
-                     xoptions=0, xpadding=gnome.ui.PAD)
+                     xoptions=0, xpadding=gu.PAD)
 
         table.attach(gtk.Label(_("Chord type")), 0, 1, 0, 1,
                      xoptions=gtk.FILL, yoptions=0)
@@ -166,17 +166,17 @@ class Gui(abstract.LessonbasedGui):
         self.g_new = gu.bButton(self.action_area, _("_New chord"),
                                 self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
-                                lambda _o: self.m_t.m_P.play_question())
+              lambda w: self.run_exception_handled(self.m_t.m_P.play_question))
         self.g_repeat_arpeggio = gu.bButton(self.action_area,
-              _("Repeat _arpeggio"), 
-              lambda _o: self.m_t.m_P.play_question_arpeggio())
+              _("Repeat _arpeggio"),
+              lambda w: self.run_exception_handled(self.m_t.m_P.play_question_arpeggio))
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"),
                                     self.give_up)
         self.practise_box.show_all()
         ##############
         # config_box #
         ##############
-        self.config_box.set_spacing(gnome.ui.PAD_SMALL)
+        self.config_box.set_spacing(gu.PAD_SMALL)
         self.add_random_transpose_gui()
         # -----------------------------------------
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
@@ -280,13 +280,13 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.flash(_("Correct"))
             for b in self.g_chordtype_box.get_children():
                 if b == button:
-                    b.get_children()[0].set_name("Bold")
+                    b.get_children()[0].set_name("BoldText")
             if g == self.m_t.ALL_CORRECT:
                 self.all_guessed_correct()
         else:
             self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
-            self.show_answer()
+            self.run_exception_handled(self.show_answer)
             self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
             self.g_give_up.set_sensitive(False)
@@ -301,12 +301,12 @@ class Gui(abstract.LessonbasedGui):
                 for question in self.m_t.m_P.m_questions:
                     if question['set'] == self.m_t.m_P.get_question()['set'] \
                         and question.get_cname() == button.get_data('type'):
-                        self.m_t.m_P.play_question(question)
+                        self.run_exception_handled(self.m_t.m_P.play_question, question)
                         return
             else:
                 for question in self.m_t.m_P.m_questions:
                     if question.get_cname() == button.get_data('type'):
-                        self.m_t.m_P.play_question(question)
+                        self.run_exception_handled(self.m_t.m_P.play_question, question)
                         return
         else:
             #Try for exact match
@@ -316,19 +316,19 @@ class Gui(abstract.LessonbasedGui):
                 if question.get_inversion() != self.m_t.m_P.get_inversion():
                     continue
                 if question.get_cname() == button.get_data('type'):
-                    self.m_t.m_P.play_question(question)
+                    self.run_exception_handled(self.m_t.m_P.play_question, question)
                     return
         # try to match, ignoring toptone
         for question in self.m_t.m_P.m_questions:
             if question.get_inversion() != self.m_t.m_P.get_inversion():
                 continue
             if question.get_cname() == button.get_data('type'):
-                self.m_t.m_P.play_question(question)
+                self.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
         # match if only type matches.
         for question in self.m_t.m_P.m_questions:
             if question.get_cname() == button.get_data('type'):
-                self.m_t.m_P.play_question(question)
+                self.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
     def on_inversion(self, button, event=None):
         if event is None:
@@ -344,11 +344,11 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.flash(_("Correct"))
             for b in self.g_inversion_box.get_children():
                 if b == button:
-                    b.get_children()[0].set_name("Bold")
+                    b.get_children()[0].set_name("BoldText")
         else:
             self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
-            self.show_answer()
+            self.run_exception_handled(self.show_answer)
             self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
             self.g_give_up.set_sensitive(False)
@@ -371,13 +371,13 @@ class Gui(abstract.LessonbasedGui):
                 continue
             if question.get_cname() == self.m_t.m_P.get_cname() \
                   and question.get_inversion() == button.get_data('inversion'):
-                self.m_t.m_P.play_question(question)
+                self.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
         # then we tries to match chord type and inversion, ignoring toptone
         for question in self.m_t.m_P.m_questions:
             if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
                    and question.get_inversion() == button.get_data('inversion'):
-                self.m_t.m_P.play_question(question)
+                self.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
     def on_toptone(self, button, event=None):
         if not event:
@@ -395,13 +395,13 @@ class Gui(abstract.LessonbasedGui):
                 continue
             if question.get_cname() == self.m_t.m_P.get_cname() \
                   and question.get_toptone() == button.get_data('toptone'):
-                self.m_t.m_P.play_question(question)
+                self.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
         # then we tries to match chord type and toptone, ignoring inversion
         for question in self.m_t.m_P.m_questions:
             if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
                     and question.get_toptone() == button.get_data('toptone'):
-                self.m_t.m_P.play_question(question)
+                sel.run_exception_handled(self.m_t.m_P.play_question, question)
                 return
     def on_toptone_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP) \
@@ -411,11 +411,11 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.flash(_("Correct"))
             for b in self.g_toptone_box.get_children():
                 if b == button:
-                    b.get_children()[0].set_name("Bold")
+                    b.get_children()[0].set_name("BoldText")
         else:
             self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
-            self.show_answer()
+            self.run_exception_handled(self.show_answer)
             self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
             self.g_give_up.set_sensitive(False)
@@ -453,16 +453,10 @@ class Gui(abstract.LessonbasedGui):
                 self.g_inversion_box.set_sensitive(self.m_t.m_P.get_inversion() != -1)
                 self.g_toptone_box.set_sensitive(self.m_t.m_P.get_toptone() != -1)
                 self.g_chordtype_box.get_children()[0].grab_focus()
-        except lessonfile.LessonfileException, e:
-            # This exception will be raised if for example the music
-            # type for a question is invalid.
-            exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
-        except mpd.MpdException, e:
-            # Invalid key variable or music code goes here.
-            exception_cleanup()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__,
+                    exception_cleanup):
+                raise e
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
         for question in self.m_t.m_P.m_questions:
@@ -485,7 +479,7 @@ class Gui(abstract.LessonbasedGui):
     def give_up(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_NEW:
             self.m_t.give_up()
-            self.show_answer()
+            self.run_exception_handled(self.show_answer)
             type_txt = self.m_t.m_P.m_chord_types[self.m_t.m_P.get_cname()]
             i = self.m_t.m_P.get_inversion()
             if i == 0:
@@ -514,20 +508,24 @@ class Gui(abstract.LessonbasedGui):
             self.g_give_up.set_sensitive(False)
             for button in self.g_chordtype_box.get_children():
                 if button.get_data('type') == self.m_t.m_P.get_cname():
-                    button.get_children()[0].set_name('Bold')
+                    button.get_children()[0].set_name('BoldText')
                 else:
                     button.get_children()[0].set_name('')
             for button in self.g_inversion_box.get_children():
                 if button.get_data('inversion') == self.m_t.m_P.get_inversion():
-                    button.get_children()[0].set_name('Bold')
+                    button.get_children()[0].set_name('BoldText')
                 else:
                     button.get_children()[0].set_name('')
             for button in self.g_toptone_box.get_children():
                 if button.get_data('toptone') == self.m_t.m_P.get_toptone():
-                    button.get_children()[0].set_name('Bold')
+                    button.get_children()[0].set_name('BoldText')
                 else:
                     button.get_children()[0].set_name('')
     def show_answer(self):
+        """
+        Show the answer in the music displayer. All callers must check
+        for exceptions.
+        """
         fontsize = self.get_int('config/feta_font_size=20')
         if self.m_t.m_P.get_question()['music'].m_musictype == 'chord':
             clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string('music'))
