@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,17 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-import gnome
 import gobject
 import re
 import soundcard
 import cfg
 
+PAD = 8
+PAD_SMALL = 4
+
 #  Prefixes used in this module:
 #  t  pack into a table, the first five parameters are table, x1, x2, y1, y2
-#  n  a widget that get its state stored in ~/.gnome/Solfege
+#  n  a widget that get its state stored in ~/.solfegerc
 #  b  the widget is packed into the first argument
 
 
@@ -319,7 +321,7 @@ class SpinButtonRangeController(object):
 
 def create_stock_menu_item(stock, txt, callback, ag, accel_key, accel_mod):
     box = gtk.HBox()
-    box.set_spacing(gnome.ui.PAD_SMALL)
+    box.set_spacing(gu.PAD_SMALL)
     im = gtk.Image()
     im.set_from_stock(stock, gtk.ICON_SIZE_MENU)
     item = gtk.ImageMenuItem(txt)
@@ -416,3 +418,45 @@ def dialog_ok(text, parent=None):
     m.destroy()
     return ret
 
+class NewLineBox(gtk.VBox):
+    def __init__(self):
+        gtk.VBox.__init__(self)
+        self.m_todo_widgets = []
+    def add_widget(self, widget):
+        self.m_todo_widgets.append(widget)
+    def show_widgets(self):
+        if 'newline' in self.m_todo_widgets:
+            self._newline_show_widgets()
+        else:
+            self._flow_show_widgets()
+    def newline(self):
+        self.m_todo_widgets.append('newline')
+    def _newline_show_widgets(self):
+        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        hbox = bHBox(self, True)
+        for n in self.m_todo_widgets:
+            if n == 'newline':
+                hbox = bHBox(self, False)
+            else:
+                hbox.pack_start(n, False)
+                sizegroup.add_widget(n)
+    def _flow_show_widgets(self):
+        w = 8
+        num_lines = len(self.m_todo_widgets) // w + 1
+        w = len(self.m_todo_widgets) // num_lines + 1
+        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        c = 0
+        for n in self.m_todo_widgets:
+            sizegroup.add_widget(n)
+            if c % w == 0:
+                hbox = bHBox(self, True, True)
+            hbox.pack_start(n, False)
+            c += 1
+        self.show_all()
+    def empty(self):
+        self.foreach(lambda w: w.destroy())
+        self.m_todo_widgets = []
+    def get_max_child_height(self):
+        return max([c.size_request()[1] for c in self.m_todo_widgets])
+
+
