@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome
+import gtk
 import abstract, idbyname, const, gu, statisticsviewer
 import soundcard, mpd, mpd.musicdisplayer
 import utils
@@ -28,9 +28,6 @@ class Teacher(idbyname.Teacher):
         if self.q_status == const.QSTATUS_NO:
             return
         self.m_P.play_question_as_choral(self.m_P.get_question())
-    def play_tonic(self):
-        if 'tonic' in self.m_P.get_question():
-            self.m_P.play_question(None, 'tonic')
 
 
 class Gui(abstract.LessonbasedGui):
@@ -45,7 +42,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, False)
-        self.practise_box.set_spacing(gnome.ui.PAD)
+        self.practise_box.set_spacing(gu.PAD)
 
         self.g_entry = gtk.Entry()
         self.g_entry.set_activates_default(True)
