@@ -105,10 +105,13 @@ class HelpBrowser(gtk.Window):
     def show_docfile(self, filename, anchor=None):
         """
         Load a html file relative to the help directory for the current
-        language, for example help/C or help/no.
+        language, for example help/C or help/no. But try the same file
+        in help/C if the file does not exist for the language we are using.
         """
         absname = os.path.join(os.getcwd(), "help",
             self.g_docviewer.m_language, filename)
+        if not os.path.exists(absname):
+            absname = os.path.join(os.getcwd(), "help", "C", filename)
         self.m_history.add(absname)
         self.g_docviewer.read_docfile(absname, anchor)
 
