@@ -3,11 +3,11 @@ import os
 import sys
 import signal
 
-class RunExternalFailed(Exception):
+class ExecutableDoesNotExist(Exception):
     def __init__(self, v):
         self.v = v
     def __str__(self):
-        return "\nRunning external program failed.\nPlease check your setup.\nThe command that failed was: '%s'" % (" ".join(self.v[1:]))
+        return _("The executable '%s' does not exist. Please check your setup.") % self.v
 
 
 __all__ = ['run_external_program']
@@ -23,7 +23,7 @@ def run_external_program(cmdstring, wdir, argument):
     v = cmdline.split()
     v = v[:1] + v
     if not os.path.exists(os.path.join(wdir, v[0])):
-        raise RunExternalFailed(v)
+        raise ExecutableDoesNotExist(v[0])
         return
     try:
         if __child_pid is not None:
