@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,15 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome
+import gtk
 import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
 import lessonfile
 import utils
 import dataparser
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingChordLessonfile
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
@@ -34,10 +34,6 @@ class Teacher(abstract.LessonbasedTeacher):
         soundcard.play_note(self.get_int('config/preferred_instrument'),
                        4, 0, mpd.notename_to_int("a'"),
                        self.get_int('config/preferred_instrument_velocity'))
-    def play_answer_arpeggio(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        self.m_P.play_question_musicformat_satb_arpeggio()
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -50,7 +46,8 @@ class Gui(abstract.LessonbasedGui):
 
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
         gu.bButton(self.action_area, _("440h_z"), lambda f, s=self: s.m_t.play_440hz())
-        self.g_play_answer = gu.bButton(self.action_area, _("_Play answer"), lambda f, s=self: s.m_t.play_answer_arpeggio())
+        self.g_play_answer = gu.bButton(self.action_area, _("_Play answer"),
+            lambda w: self.run_exception_handled(self.m_t.m_P.play_question_musicformat_satb_arpeggio))
         self.practise_box.show_all()
         ##############
         # config_box #
@@ -67,16 +64,9 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
             self.g_play_answer.set_sensitive(True)
             self.m_t.play_440hz()
-        except mpd.MpdException, e:
-            # since we could not play the new question, it is possible,
-            # if the user are fast, that the last question is still playing.
-            exception_cleanup()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e)
-        except lessonfile.LessonfileException, e:
-            # caused by for example invalid musicformat
-            exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+                raise e
     def on_start_practise(self):
         self.update_gui_after_lessonfile_change()
         # if we have not m_P, then parsing of the lessonfile failed,
