@@ -1,9 +1,15 @@
-#!/usr/bin/python2.2
+#!/usr/bin/python2.3
+if __name__ == "__main__":
+    import sys
+    sys.path.append("src")
+    import i18n
+    i18n.setup(".")
+
 
 import pygtk
 pygtk.require("2.0")
 import profile, os
-import sys, types
+import sys
 
 if os.getcwd()[-4:] == "test":
    sys.path.append("..")
